@@ -64,7 +64,7 @@ G_DEFINE_TYPE (EvSidebar, ev_sidebar, GTK_TYPE_VBOX)
 		(G_TYPE_INSTANCE_GET_PRIVATE ((object), EV_TYPE_SIDEBAR, EvSidebarPrivate))
 
 static void
-ev_sidebar_destroy (GtkObject *object)
+ev_sidebar_dispose (GObject *object)
 {
 	EvSidebar *ev_sidebar = EV_SIDEBAR (object);
 
@@ -79,7 +79,7 @@ ev_sidebar_destroy (GtkObject *object)
 	}
 		
 	   
-	(* GTK_OBJECT_CLASS (ev_sidebar_parent_class)->destroy) (object);
+	G_OBJECT_CLASS (ev_sidebar_parent_class)->dispose (object);
 }
 
 static void
@@ -175,17 +175,11 @@ ev_sidebar_get_property (GObject *object,
 static void
 ev_sidebar_class_init (EvSidebarClass *ev_sidebar_class)
 {
-	GObjectClass *g_object_class;
-	GtkWidgetClass *widget_class;
-	GtkObjectClass *gtk_object_klass;
- 
-	g_object_class = G_OBJECT_CLASS (ev_sidebar_class);
-	widget_class = GTK_WIDGET_CLASS (ev_sidebar_class);
-	gtk_object_klass = GTK_OBJECT_CLASS (ev_sidebar_class);
-	   
+        GObjectClass *g_object_class = G_OBJECT_CLASS (ev_sidebar_class);
+
 	g_type_class_add_private (g_object_class, sizeof (EvSidebarPrivate));
-	   
-	gtk_object_klass->destroy = ev_sidebar_destroy;
+
+	g_object_class->dispose = ev_sidebar_dispose;
 	g_object_class->get_property = ev_sidebar_get_property;
 	g_object_class->set_property = ev_sidebar_set_property;
 
@@ -237,7 +231,7 @@ ev_sidebar_select_button_press_cb (GtkWidget      *widget,
 		gtk_widget_get_allocation (widget, &allocation);
 		width = allocation.width;
 		gtk_widget_set_size_request (ev_sidebar->priv->menu, -1, -1);
-		gtk_widget_size_request (ev_sidebar->priv->menu, &requisition);
+                gtk_widget_get_preferred_size (ev_sidebar->priv->menu, &requisition, NULL);
 		gtk_widget_set_size_request (ev_sidebar->priv->menu,
 					     MAX (width, requisition.width), -1);
 		
@@ -261,10 +255,10 @@ ev_sidebar_select_button_key_press_cb (GtkWidget   *widget,
 {
 	EvSidebar *ev_sidebar = EV_SIDEBAR (user_data);
 	   
-	if (event->keyval == GDK_space ||
-	    event->keyval == GDK_KP_Space ||
-	    event->keyval == GDK_Return ||
-	    event->keyval == GDK_KP_Enter) {
+	if (event->keyval == GDK_KEY_space ||
+	    event->keyval == GDK_KEY_KP_Space ||
+	    event->keyval == GDK_KEY_Return ||
+	    event->keyval == GDK_KEY_KP_Enter) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 		gtk_menu_popup (GTK_MENU (ev_sidebar->priv->menu),
 			        NULL, NULL, ev_sidebar_menu_position_under, widget,
